@@ -319,11 +319,11 @@ void on_node_info(void* object, const struct pw_node_info* info) {
 
       uint64_t serial = SPA_ID_INVALID;
 
-      util::str_to_num(target_object, serial);
-
-      if (target_object != pm->input_device.name) {
-        ignore_input_stream = true;
-      } else if (serial != SPA_ID_INVALID && serial != pm->input_device.serial) {
+      if (util::str_to_num(target_object, serial)) {
+        if (serial != SPA_ID_INVALID && (serial != pm->input_device.serial && serial != pm->ee_source_node.serial)) {
+          ignore_input_stream = true;
+        }
+      } else if (target_object != pm->input_device.name && target_object != pm->ee_source_node.name) {
         ignore_input_stream = true;
       }
 
@@ -346,11 +346,11 @@ void on_node_info(void* object, const struct pw_node_info* info) {
 
       uint64_t serial = SPA_ID_INVALID;
 
-      util::str_to_num(target_object, serial);
-
-      if (target_object != pm->output_device.name) {
-        ignore_output_stream = true;
-      } else if (serial != SPA_ID_INVALID && serial != pm->output_device.serial) {
+      if (util::str_to_num(target_object, serial)) {
+        if (serial != SPA_ID_INVALID && (serial != pm->output_device.serial && serial != pm->ee_sink_node.serial)) {
+          ignore_output_stream = true;
+        }
+      } else if (target_object != pm->output_device.name && target_object != pm->ee_sink_node.name) {
         ignore_output_stream = true;
       }
 
@@ -573,7 +573,9 @@ void on_node_info(void* object, const struct pw_node_info* info) {
         pm->stream_input_changed.emit(nd_info_copy);
       });
     }
-  } else if (nd->nd_info->media_class == tags::pipewire::media_class::source) {
+  }
+
+  if (nd->nd_info->media_class == tags::pipewire::media_class::source) {
     const auto nd_info_copy = *nd->nd_info;
 
     util::idle_add([=]() {
@@ -1772,7 +1774,7 @@ void PipeManager::disconnect_stream(const uint& stream_id) const {
   sync_wait_unlock();
 }
 
-void PipeManager::set_node_volume(pw_proxy* proxy, const uint& n_vol_ch, const float& value) {
+void PipeManager::set_node_volume(pw_proxy* proxy, const uint& n_vol_ch, const float& value) const {
   std::array<float, SPA_AUDIO_MAX_CHANNELS> volumes{};
 
   std::ranges::fill(volumes, 0.0F);
@@ -1782,20 +1784,28 @@ void PipeManager::set_node_volume(pw_proxy* proxy, const uint& n_vol_ch, const f
 
   auto builder = SPA_POD_BUILDER_INIT(buffer.data(), sizeof(buffer));
 
+  lock();
+
   pw_node_set_param(
       (struct pw_node*)proxy, SPA_PARAM_Props, 0,
       (spa_pod*)spa_pod_builder_add_object(&builder, SPA_TYPE_OBJECT_Props, SPA_PARAM_Props, SPA_PROP_channelVolumes,
                                            SPA_POD_Array(sizeof(float), SPA_TYPE_Float, n_vol_ch, volumes.data())));
+
+  sync_wait_unlock();
 }
 
-void PipeManager::set_node_mute(pw_proxy* proxy, const bool& state) {
+void PipeManager::set_node_mute(pw_proxy* proxy, const bool& state) const {
   std::array<char, 1024U> buffer{};
 
   auto builder = SPA_POD_BUILDER_INIT(buffer.data(), sizeof(buffer));
 
+  lock();
+
   pw_node_set_param((pw_node*)proxy, SPA_PARAM_Props, 0,
                     (spa_pod*)spa_pod_builder_add_object(&builder, SPA_TYPE_OBJECT_Props, SPA_PARAM_Props,
                                                          SPA_PROP_mute, SPA_POD_Bool(state)));
+
+  sync_wait_unlock();
 }
 
 auto PipeManager::count_node_ports(const uint& node_id) -> uint {
